@@ -1,11 +1,30 @@
 import json
 import requests
+try:
+    from django.conf import settings
+except Exception as e:
+    pass
 # This is a class that is designed to include all methods and functions one needs to make an A.P.I. call
 class API(object):
 
     _base_url = "https://dev.bankingservices.nashglobal.co/api/banks"
     _base_url_third_party_banking = "https://dev.3p.bankingservices.nashglobal.co/api"
 
+    _auth_token_url = None
+    _client_id = None
+    _client_secret = None
+    _identity_token = None
+
+    try:
+        _client_id = getattr(
+            settings, 'OAUTH2_CLIENT_ID', _client_id)
+        _client_secret = getattr(
+            settings, 'CLIENT_SECRET', _client_secret)
+        _auth_token_url = getattr(
+            settings, 'OAUTH2_TOKEN_URL', _auth_token_url)
+    except Exception as e:
+        pass
+
     _full_url = ""
 
     # Most API calls require headers, params and payloads
@@ -27,6 +46,19 @@ class API(object):
 
         requests.packages.urllib3.disable_warnings()
 
+    def set_identity_token(self,identity_token):
+        self._identity_token = identity_token
+        return self
+
+    def refresh_identity_token(self):
+        _payload = {
+            'grant_type': 'client_credentials',
+            'client_id': self._client_id,
+            'client_secret': self._client_secret
+        }
+        self._identity_token = requests.request(
+            "POST", self._auth_token_url, data=_payload)
+
     # There are 3 types of API requests that most APIs use, POST, GET and PUT
     # This method will take the payload or data to be sent and send it to the required API url
     # using the desired method and returns the response
@@ -37,6 +69,12 @@ class API(object):
         else:
             self._payload = payload
         
+        if self._headers is not None and self.get_identity_token is not None:
+            if self.get_identity_token.status_code == 200:
+                self._headers.update({
+                    'Authorization':f"Bearer {self.get_identity_token.json().get('access_token',None)}"
+                })
+        
         try:
             if method == 'POST':
                 self._response = requests.post(self.get_full_url(), headers=self._headers, params=self._params,
@@ -93,4 +131,8 @@ class API(object):
         return self._base_url
 
     def get_base_url_third_party_banking(self):
-        return self._base_url_third_party_banking
\ No newline at end of file
+        return self._base_url_third_party_banking
+
+    @property
+    def get_identity_token(self):
+        return self._identity_token
\ No newline at end of file
